@@ -25,6 +25,9 @@ import time
 import logging
 import inspect
 import Cookie
+import base64
+import hmac
+import cPickle as pickle
 from functools import partial
 
 from mongrel2 import Mongrel2Connection
@@ -192,6 +195,12 @@ class MessageHandler(object):
         """
         pass
 
+    @property
+    def db_conn(self):
+        """Short hand to put database connection in easy reach of handlers
+        """
+        return self.application.db_conn
+
     def unsupported(self):
         """Called anytime an unsupported request is made.
         """
@@ -285,7 +294,7 @@ class MessageHandler(object):
                     logging.debug('Handler had no return value: %s' % fun)
                     return ''
             except Exception, e:
-                logging.error(e)
+                logging.error(e, exc_info=True)
                 rendered = self.unsupported()
                 
             self._finished = True
@@ -336,7 +345,8 @@ class WebMessageHandler(MessageHandler):
     def body(self):
         return self._payload[self._BODY]
 
-    def set_body(self, body, status_code=self._SUCCESS_CODE, headers=None):
+    def set_body(self, body, status_code=_SUCCESS_CODE, 
+                 headers=None):
         """
         """
         self._payload[self._BODY] = body
@@ -409,8 +419,9 @@ class WebMessageHandler(MessageHandler):
         """Retrieve a cookie from message, if present, else fallback to
         `default` keyword. Accepts a secret key to validate signed cookies.
         """
+        value = None
         if key in self.message.cookies:
-            return self.message.cookies[key].value
+            value = self.message.cookies[key].value
         if secret and value:
             dec = cookie_decode(value, secret) 
             return dec[1] if dec and dec[0] == key else None        
@@ -508,7 +519,8 @@ class WebMessageHandler(MessageHandler):
 class Brubeck(object):
     def __init__(self, mongrel2_pair=None, handler_tuples=None, pool=None,
                  no_handler=None, base_handler=None, template_loader=None,
-                 log_level=logging.INFO, login_url=None,
+                 log_level=logging.INFO, login_url=None, db_conn=None,
+                 cookie_secret=None,
                  *args, **kwargs):
         """Brubeck is a class for managing connections to Mongrel2 servers
         while providing an asynchronous system for managing message handling.
@@ -553,9 +565,15 @@ class Brubeck(object):
         if self.base_handler is None:
             self.base_handler = WebMessageHandler
 
+        # A database connection is optional. The var name is now in place
+        self.db_conn = db_conn
+
         # Login url is optional
         self.login_url = login_url
             
+        # This must be set to use secure cookies
+        self.cookie_secret = cookie_secret
+
         # Any template engine can be used. Brubeck just needs a function that
         # loads the environment without arguments. 
         if callable(template_loader):
